package edu.uiuc.ncsa.myproxy;


import java.util.HashMap;
import java.util.Map;

/**
 * Properties for the MyProxyService facade. This supports a configurable hostname and various levels of
 * assurance.
 * <p>Created by Jeff Gaynor<br>
 * on May 14, 2010 at  10:16:44 AM
 */
public class ServiceFacadeConfiguration {
    /**
     * Sets the name of the server and default port. The levels of assurance as passed as
     * a map of strings and port numbers. A call for a specific level of assurance will
     * simply look up the port number and use that. This allows for changing the LOA
     * port numbers in the configuration rather than having to worry about coding them.
     * @param hostname  Fully qualified name of the MyProxy server
     * @param port The port for the server
     * @param loas A map consisting of the level of assurance names and port numbers.
     */
    public ServiceFacadeConfiguration(String hostname, int port, Map<String, Integer> loas) {
        this.hostname = hostname;
        this.loas = loas;
        this.port = port;
    }

    /**
     * Convenience call when there are no LOAs.
     * @param hostname
     * @param port
     */
    public ServiceFacadeConfiguration(String hostname, int port) {
        this.hostname = hostname;
        this.port = port;
        this.loas = new HashMap<String, Integer>();
    }

    Map<String, Integer> loas;

    String hostname;
    int port = -1;

    /**
     * Get the fully qualified hostname for the MyProxy server
     * @return
     */
    public String getHostname() {
        return hostname;
    }


    /**
     * Get the port for the MyProxy Server.
     * @return
     */
    public int getPort() {
        return port;
    }

}
